---
title: <span class="badge object-type-scalar"></span> Euro
---
# <span class="badge object-type-scalar"></span> Euro

Currency: Euro (€)

## Definition

```python
# Currency: Euro (€)
Euro: typing.Literal["currencyEUR"] = "currencyEUR"
```
